# Neural Network
![v1](https://img.shields.io/badge/Version-v1-green)
![Static Badge](https://img.shields.io/badge/Made_in-Python-blue)

A neural network library built without any AI libraries, only NumPy.

## How to Use
You should use `pip install ptl-neural-network` to get the CLI.

The command syntax is `ptl-neural train/run`. The above guide also works with the CLI, except don't run `train.py` or `run.py`.
